@@ -212,14 +212,9 @@ class N2PComponent:
         resultsParameters = self._create_n2paraminputresult(sections, aveSections, cornerData, aveNodes, variation,
                                                             realPolar, coordsys, v1, v2)
 
-        if self.__result_father__.__loadCase_father__.TypeLC == "DERIVED":
-            results = self.__result_father__.__loadCase_father__._N2PLoadCase__n2loadcase.CalculateLastArray(
-                      resultsParameters, 0)
-
-        else:
-            results = \
+        results = \
             self.__result_father__.__loadCase_father__.__modelFather__._N2PModelContent__vzmodel.CalculateArrayLastResult(
-                resultsParameters, 0)
+            resultsParameters, 0)
 
         if results[1] == 1:
             return(np.array(results[0], np.float64),'NODES')
