@@ -359,6 +359,13 @@ own information message. Use the following structure as a standard message (I +
             message = f"W300: there are more dimensions than points as arguments in n2p.envelope"
             N2PLog._N2PLog__logger.warning(message)
 
+        @staticmethod
+        def W301(name) -> None:
+            """ Warning raised when the name for the new derived load case already exist
+            """
+            message = f"W301: the name for the new load case already exist. It has been rename to '{name}'"
+            N2PLog._N2PLog__logger.warning(message)
+
     # ------------------------------------------------------------------------------------------------------------------
 
     ############################################  ERROR  ###############################################################
