@@ -1031,8 +1031,8 @@ class N2PModelContent:
 
         """ Method of N2PModelContent that returns a list of tuples of N2PElement and two N2PNode of that element. 
         The two nodes define the edge of the element that is contained in the free edge of the mesh If a domain is selected, 
-        the tuple will only be searched in that domain. Notice that connectors, although may be given in the domain, are never 
-        included in the free edges.
+        the tuple will only be searched in that domain. Notice that connectors, although they may be given in the domain,
+        they are never included in the free edges.
 
         Args:
             domain: list[N2PElement, N2PConnector, ...] -> Optional. Set the domain where to look for the adjacent elements
@@ -1066,7 +1066,7 @@ class N2PModelContent:
         must be passed as arguments. The name of the new derived loadcase must be set, but the id not. The id will be a
         negative integer. The loadcases|frames must have this structure: <LCXX:FRYY>. Examples of formulas:
             - formula = "<LC1:FR1>+2*<LC2:FR1>+0.5*<LC5:FR3>"
-            - formula = "<0.5*LC1:FR2>"
+            - formula = "0.5*<LC1:FR2>"
             - formula = "5*<LC2:FR3>-2*<LC3:FR3>"
 
         Args:
@@ -1076,6 +1076,10 @@ class N2PModelContent:
         Returns:
             N2PLoadCase -> Derived load case
         """
+        # Comprobamos que el nombre no se repite:
+        if name in [lc.Name for lc in self.LoadCases]:
+            name += "-1"
+            N2PLog.Warning.W301(name)
 
         # Genera una instancia de un N2LoadCase the VizzerClasses
         cs_lc = N2LoadCase(self.__vzmodel, name, formula)
@@ -1085,7 +1089,48 @@ class N2PModelContent:
 
         # Se transforma el caso de carga de VizzerClasses en un N2PLoadCase de python
         py_lc = N2PLoadCase(cs_lc.ID, cs_lc.IDOriginal, cs_lc.Increments, cs_lc.IncrementsNumberList, cs_lc.IsComplex,
-                            cs_lc.TypeLoadCase, cs_lc.Name, cs_lc.Results, cs_lc.SolutionType, self, cs_lc)
+                            cs_lc.TypeLoadCase, cs_lc.Name, cs_lc.Results, cs_lc.SolutionType, cs_lc.Solver, self, cs_lc)
+
+        # Se añade el caso de carga de csharp a N2ModelContent de Vizzer
+        self.__vzmodel.LoadCases.Add(cs_lc)
+
+        # Se añade el case de carga de python a N2PModelContent
+        self.__load_cases__.append(py_lc)
+
+        return py_lc
+
+    def new_envelope_loadcase(self, name: str, formula: str) -> N2PLoadCase:
+        """Method of N2PModelContent that generate a new N2PLoadCase that is the envelope of the load cases and increments
+        selected.
+
+        The id is automatically generated. It will be negative, starting at -1. If the new load case use a derivated or
+        envelope load case use LCD1 in the formula instead of LC-1:
+
+        Args:
+            name: str -> Name of the envelope load case. It mustn't be repeated.
+            formula: str -> formula that define the loadcases and increments must have this structure: <LCXX:FRYY>
+                exmaple: "<LC1:FR1>,<LCD2:FR1>,<LC2:FR10>"
+
+        Returns:
+            N2PLoadCase
+        """
+        # Comprobamos que el nombre no se repite:
+        if name in [lc.Name for lc in self.LoadCases]:
+            name += "-1"
+            N2PLog.Warning.W301(name)
+
+        # Comprobamos que la formula está bien:
+        formula = formula.replace("-", "D").replace(" ", "")
+
+        # Genera una instancia de un N2LoadCase the VizzerClasses
+        cs_lc = N2LoadCase(self.__vzmodel, name, formula, True)
+
+        # Método de N2LoadCase que pone todoo en su sitio
+        cs_lc.RecalculateLCInfo2Formule()
+
+        # Se transforma el caso de carga de VizzerClasses en un N2PLoadCase de python
+        py_lc = N2PLoadCase(cs_lc.ID, cs_lc.IDOriginal, cs_lc.Increments, cs_lc.IncrementsNumberList, cs_lc.IsComplex,
+                            cs_lc.TypeLoadCase, cs_lc.Name, cs_lc.Results, cs_lc.SolutionType, cs_lc.Solver, self, cs_lc)
 
         # Se añade el caso de carga de csharp a N2ModelContent de Vizzer
         self.__vzmodel.LoadCases.Add(cs_lc)
@@ -1096,6 +1141,7 @@ class N2PModelContent:
         return py_lc
     # ------------------------------------------------------------------------------------------------------------------
 
+
     ####################################################################################################################
     #####################################     Results by LCs & Incr      ################################################
     ####################################################################################################################
@@ -1230,6 +1276,7 @@ def load_model(path: str, parallelprocessing: bool = False, file_type: str = Non
         """
     if not os.path.exists(path):
         N2PLog.Critical.C108(path)
+        return "ERROR"
         # sys.exit()
 
     if path.split(".")[-1] in BINARY_EXTENSIONS and file_type == "InputFileNastran":
